@@ -24,12 +24,17 @@ import os
 import logging
 
 from PyQt4 import QtGui, QtCore
+from PyQt4.QtGui import QMainWindow
+from PyQt4.QtCore import QThread
+
 from yapsy import PluginManager
 from PIL import ImageQt
+from PIL import Image
 from fysom import FysomError
 
 from ayab_gui import Ui_MainWindow
 from plugins.ayab_plugin.firmware_flash import FirmwareFlash
+from ayab_about import Ui_AboutForm
 
 ## Temporal serial imports.
 import serial
@@ -39,7 +44,7 @@ import serial.tools.list_ports
 logging.basicConfig(level=logging.DEBUG)
 
 
-class GuiMain(QtGui.QMainWindow):
+class GuiMain(QMainWindow):
     """GuiMain is the main object that handles the instance of AYAB's GUI from ayab_gui.UiForm .
 
     GuiMain inherits from QMainWindow and instanciates a window with the form components form ayab_gui.UiForm.
@@ -88,7 +93,7 @@ class GuiMain(QtGui.QMainWindow):
           pass
 
         if not plugin_name:
-            plugin_name = window.ui.module_dropdown.currentText()
+            plugin_name = self.ui.module_dropdown.currentText()
         plugin_o = self.pm.getPluginByName(plugin_name)
         self.enabled_plugin = plugin_o
 
@@ -125,11 +130,19 @@ class GuiMain(QtGui.QMainWindow):
         self.connect(self, QtCore.SIGNAL("display_blocking_pop_up_signal(QString)"), self.display_blocking_pop_up, QtCore.Qt.BlockingQueuedConnection)
         self.connect(self, QtCore.SIGNAL("display_pop_up_signal(QString, QString)"), self.display_blocking_pop_up)
         self.ui.actionQuit.activated.connect(QtCore.QCoreApplication.instance().quit)
+        self.ui.actionAbout.activated.connect(self.open_about_ui)
+        self.ui.actionMirror.activated.connect(self.mirror_image)
+        self.ui.actionInvert.activated.connect(self.invert_image)
+        self.ui.actionRotate_Left.activated.connect(self.rotate_left)
+        self.ui.actionRotate_Right.activated.connect(self.rotate_right)
 
-    def load_image_on_scene(self, image_str):
+    def load_image_from_string(self, image_str):
         """Loads an image into self.ui.image_pattern_view using a temporary QGraphicsScene"""
-        self.__pil_image = ImageQt.Image.open(image_str)
-        self.__qt_image = ImageQt.ImageQt(self.__pil_image)
+        self.pil_image = Image.open(image_str)
+        self.load_pil_image_on_scene(self.pil_image)
+
+    def load_pil_image_on_scene(self, image_obj):
+        self.__qt_image = ImageQt.ImageQt(image_obj)
         self.__qpixmap = QtGui.QPixmap.fromImage(self.__qt_image)
         self.__qscene = QtGui.QGraphicsScene()
         self.__qscene.addPixmap(self.__qpixmap)
@@ -158,17 +171,77 @@ class GuiMain(QtGui.QMainWindow):
             return True
 
     def conf_button_function(self):
-        self.enabled_plugin.plugin_object.configure(parent_ui=self)
+        self.enabled_plugin.plugin_object.configure(self)
 
     def file_select_dialog(self):
         file_selected_route = QtGui.QFileDialog.getOpenFileName(self)
         self.update_file_selected_text_field(file_selected_route)
-        self.load_image_on_scene(str(file_selected_route))
+        self.load_image_from_string(str(file_selected_route))
 
     def generate_firmware_ui(self):
-      self.__flash_ui = FirmwareFlash()
+      self.__flash_ui = FirmwareFlash(self)
       self.__flash_ui.show()
 
+    def open_about_ui(self):
+        self.__AboutForm = QtGui.QFrame()
+        self.__about_ui = Ui_AboutForm()
+        self.__about_ui.setupUi(self.__AboutForm)
+        self.__AboutForm.show()
+
+    def invert_image(self):
+        '''Public invert current Image function.'''
+        self.apply_image_transform("invert")
+
+    def mirror_image(self):
+        '''Public mirror current Image function.'''
+        self.apply_image_transform("mirror")
+
+    def rotate_left(self):
+        '''Public rotate left current Image function.'''
+        self.apply_image_transform("rotate", -90.0)
+
+    def rotate_right(self):
+        '''Public rotate right current Image function.'''
+        self.apply_image_transform("rotate", 90.0)
+
+    def apply_image_transform(self, transform_type, *args):
+        '''Executes an image transform specified by key and args.
+
+        Calls a function from transform_dict, forwarding args and the image,
+        and replaces the QtImage on scene.
+        '''
+        #TODO add try-catch
+        transform_dict = {
+            'invert': self.__invert_image,
+            'mirror': self.__mirror_image,
+            'rotate': self.__rotate_image,
+        }
+        transform = transform_dict.get(transform_type)
+        image = self.pil_image
+        if not image:
+            return
+        #executing transform
+        image = transform(image, args)
+        #update the view
+        self.pil_image = image
+        self.load_pil_image_on_scene(self.pil_image)
+
+    def __rotate_image(self, image, args):
+        if not args:
+            logging.debug("image not altered on __rotate_image.")
+            return image
+        rotated_image = image.rotate(args[0])
+        return rotated_image
+
+    def __invert_image(self, image, args):
+        import PIL.ImageChops
+        inverted_image = PIL.ImageChops.invert(image)
+        return inverted_image
+
+    def __mirror_image(self, image, args):
+        import PIL.ImageOps
+        mirrored_image = PIL.ImageOps.mirror(image)
+        return mirrored_image
 
     def getSerialPorts(self):
       """
@@ -177,7 +250,7 @@ class GuiMain(QtGui.QMainWindow):
       return list(serial.tools.list_ports.grep("USB"))
 
 
-class GenericThread(QtCore.QThread):
+class GenericThread(QThread):
     '''A generic thread wrapper for functions on threads.'''
 
     def __init__(self, function, *args, **kwargs):
