@@ -39,10 +39,17 @@ class AyabPluginControl(KnittingPlugin):
 
   def onconfigure(self, e):
     logging.debug("called onconfigure on TestingKnittingPlugin")
-    conf = self.get_configuration_from_ui(self.__parent_ui)
+    #print ', '.join("%s: %s" % item for item in vars(e).items())
+    #FIXME: substitute setting parent_ui from self.__parent_ui
+    #self.__parent_ui = e.event.parent_ui
+    parent_ui = self.__parent_ui
+    pil_image = parent_ui.pil_image
+
+    conf = self.get_configuration_from_ui(parent_ui)
     #TODO: detect if previous conf had the same image to avoid re-generating.
+
     try:
-      self.__image = ayab_image.ayabImage(self.conf["filename"], self.conf["num_colors"])
+      self.__image = ayab_image.ayabImage(pil_image, self.conf["num_colors"])
     except:
       self.__notify_user("You need to set an image.", "error")
       return
@@ -55,7 +62,7 @@ class AyabPluginControl(KnittingPlugin):
       self.__image.setStartLine(conf.get("start_line"))
 
     self.validate_configuration(conf)
-
+    self.__emit_progress(0)
     return
 
   def validate_configuration(self, conf):
@@ -417,7 +424,7 @@ class AyabPluginControl(KnittingPlugin):
               if rcvMsg == 'cnfInfo':
                   if rcvParam == API_VERSION:
                       curState = 's_start'
-                      self.__wait_for_user_action("Please init machine")
+                      self.__wait_for_user_action("Please init machine. (Set the carriage to mode KC-I or KC-II and move the carriage over the left turn mark).")
                   else:
                       logging.error("wrong API version: " + str(rcvParam)
                                         + (" (expected: )") + str(API_VERSION))
@@ -433,6 +440,7 @@ class AyabPluginControl(KnittingPlugin):
                       curState = 's_operate'
                       self.__wait_for_user_action("Ready to Operate")
                   else:
+                      self.__wait_for_user_action("Device not ready, configure and try again.")
                       logging.error("device not ready")
                       return
 
@@ -443,7 +451,7 @@ class AyabPluginControl(KnittingPlugin):
                       curState = 's_finished'
 
           if curState == 's_finished':
-              self.__wait_for_user_action("Image finished")
+              self.__wait_for_user_action("Image transmission finished. Please knit until you hear the double beep sound.")
               return
 
           oldState = curState
